@@ -9,7 +9,7 @@ use Carp;
 use Try::Tiny;
 use Data::Dumper;
 
-our $VERSION = '0.007';
+our $VERSION = '0.009';
 
 register logged_in_user => sub
 {
@@ -626,6 +626,19 @@ register delete_permission => sub
     return $provider->delete_permission( $params, $opts );
 };
 
+register provider => sub
+{
+    my $dsl    = shift;
+    my $params = shift;
+    my $opts   = shift;
+    my $app    = $dsl->app;
+    my $conf   = plugin_setting();
+
+    my $provider = _provider( $dsl, $conf, _try_realm( $app, $opts ) );
+
+    return $provider;
+};
+
 sub _require_login
 {
     my $dsl     = shift;
@@ -790,7 +803,7 @@ Dancer2::Plugin::Auth::YARBAC - Yet Another Role Based Access Control Framework
 
 =head1 VERSION
 
-version 0.007
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -842,6 +855,20 @@ In this example we'll use the 'Database' provider:
           # If true, password must contain a number
           numbers: 1
 
+In your app the order of modules loaded is important. Ensure you set 
+the session module before YARBAC. YARBAC doesn't care which session 
+module you use so long as one is loaded. 
+If you're using the L<Dancer2::Plugin::Auth::YARBAC::Provider::Database> 
+backend provider ensure you've also loaded L<Dancer2::Plugin::Database> 
+before YARBAC.
+
+  package MyPackage;
+     
+  use Dancer2;
+  use Dancer2::Plugin::Database;
+  use Dancer2::Session::Cookie;
+  use Dancer2::Plugin::Auth::YARBAC;
+
 The configuration you provide will depend on the backend provider module 
 you choose to use. In this example we're assuming the Database 
 backend provider, see: 
@@ -855,7 +882,7 @@ This framework was heavily inspired by the excellent L<Dancer::Plugin::Auth::Ext
 framework which I'd highly recommend. 
 YARBAC was designed to support secure password checking, enforced password hashing, 
 multiple authentication realms and the ability to create your own backend provider. 
-YARBAC was also designed to to be as flexialbe and as feature rich as possible 
+YARBAC was also designed to to be as flexible and as feature rich as possible 
 in the hope that I'll never have to write RBAC code for Dancer again. :) 
 While similar to Extensible in some ways, this framework has some significantly 
 different approaches. 
@@ -998,14 +1025,18 @@ was correct and then report back with a hashref.
 
 =item login - Attempts login and then redirects.
 
-  post '/login' => sub {
+  any ['get', 'post'] => '/login' => sub {
     # Optionally set the realm:
     # return login( { username => params->{username}, 
     #                 password => params->{password} }, 
     #               { realm => params->{realm} } );
-
-    return login( { username => params->{username}, 
-                    password => params->{password} } );
+                  
+    if ( params->{username} && params->{password} ) {
+        return login( { username => params->{username},
+                        password => params->{password} } );
+    }
+          
+    template 'login', {};
   };
 
 If the user authenticates successfully this will redirect the user to whatever 
@@ -1985,6 +2016,22 @@ is false.
 
 =back
 
+=head1 MISCELLANEOUS
+
+=over
+
+=item provider - Returns the backend provider object
+
+  get '/provider' => sub {
+    my $provider = provider();
+    #.......         
+  };
+
+Keyword 'provider' returns the backend provider object.
+Wouldn't recommend it without a good reason.
+
+=back
+
 =head1 AUTHOR
 
 Sarah Fuller <sarah@averna.id.au>
